pub struct DatasetRef {
pub dataset_id: String,
pub uri: Option<String>,
pub sha256: String,
pub format: String,
pub split: Option<String>,
pub size_bytes: Option<u64>,
pub description: Option<String>,
pub extensions: Option<Struct>,
}Fields
dataset_id: Stringuri: Option<String>sha256: Stringformat: Stringsplit: Option<String>size_bytes: Option<u64>description: Option<String>extensions: Option<Struct>Implementations
Sourceimpl DatasetRef
impl DatasetRef
Sourcepub fn split(&self) -> &str
pub fn split(&self) -> &str
Returns the value of split, or the default value if split is unset.
Sourcepub fn size_bytes(&self) -> u64
pub fn size_bytes(&self) -> u64
Returns the value of size_bytes, or the default value if size_bytes is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.