pub struct ObjectiveSpec {
pub metric_key: String,
pub direction: String,
pub target: Option<f64>,
pub min_delta: Option<f64>,
pub tolerance: Option<f64>,
pub report_file: Option<String>,
pub report_task_id: Option<String>,
pub weight: Option<f64>,
pub description: Option<String>,
pub extensions: Option<Struct>,
}Fields
metric_key: Stringdirection: Stringtarget: Option<f64>min_delta: Option<f64>tolerance: Option<f64>report_file: Option<String>report_task_id: Option<String>weight: Option<f64>description: Option<String>extensions: Option<Struct>Implementations
Sourceimpl ObjectiveSpec
impl ObjectiveSpec
Sourcepub fn target(&self) -> f64
pub fn target(&self) -> f64
Returns the value of target, or the default value if target is unset.
Sourcepub fn min_delta(&self) -> f64
pub fn min_delta(&self) -> f64
Returns the value of min_delta, or the default value if min_delta is unset.
Sourcepub fn tolerance(&self) -> f64
pub fn tolerance(&self) -> f64
Returns the value of tolerance, or the default value if tolerance is unset.
Sourcepub fn report_file(&self) -> &str
pub fn report_file(&self) -> &str
Returns the value of report_file, or the default value if report_file is unset.
Sourcepub fn report_task_id(&self) -> &str
pub fn report_task_id(&self) -> &str
Returns the value of report_task_id, or the default value if report_task_id is unset.
Sourcepub fn weight(&self) -> f64
pub fn weight(&self) -> f64
Returns the value of weight, or the default value if weight is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.